@@ -1,9 +1,9 @@
 /* Test of strerror_r() function.
-   Copyright (C) 2007-2022 Free Software Foundation, Inc.
+   Copyright (C) 2007-2025 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3, or (at your option)
+   the Free Software Foundation, either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -57,7 +57,7 @@ main (void)
   /* POSIX requires strerror (0) to succeed.  Reject use of "Unknown
      error", but allow "Success", "No error", or even Solaris' "Error
      0" which are distinct patterns from true out-of-range strings.
-     http://austingroupbugs.net/view.php?id=382  */
+     https://austingroupbugs.net/view.php?id=382  */
   errno = 0;
   buf[0] = '\0';
   ret = strerror_r (0, buf, sizeof buf);
@@ -84,7 +84,7 @@ main (void)
      EINVAL for out-of-range values.  On error, POSIX permits buf to
      be empty, unchanged, or unterminated, but these are not useful,
      so we guarantee NUL-terminated truncated contents for all but
-     size 0.  http://austingroupbugs.net/view.php?id=398.  Also ensure
+     size 0.  https://austingroupbugs.net/view.php?id=398.  Also ensure
      that no out-of-bounds writes occur.  */
   {
     int errs[] = { EACCES, 0, -3, };
@@ -174,5 +174,5 @@ main (void)
   }
 #endif
 
-  return 0;
+  return test_exit_status;
 }
